Destrieux Surface


Notes
-----
Anatomical parcellation of the cortex based on sulco-gyral patterns
(Destrieux et al, 2010) distributed with Freesurfer (Dale et al, 1999,
Fischl et al, 1999) in fsaverage5 standard surface space.

Content
-------
    :'annot_left': parcellation on left hemisphere in freesurfer annot format
    :'annot_right': parcellation on right hemisphere in freesurfer annot format


References
----------

Destrieux et al, (2010). Automatic parcellation of human cortical gyri and
sulci using standard anatomical nomenclature. NeuroImage 53.
http://dx.doi.org/10.1016/j.neuroimage.2010.06.010

Dale et al, (1999). Cortical surface-based analysis.I. Segmentation and
surface reconstruction. Neuroimage 9.
http://dx.doi.org/10.1006/nimg.1998.0395

Fischl et al, (1999). Cortical surface-based analysis. II: Inflation,
flattening, and a surface-based coordinate system. Neuroimage 9.
http://dx.doi.org/10.1006/nimg.1998.0396
